function v=compute_ekman_surge_xmax(shelf_width,phi,foreward_speed,phi_spiral)
% Computes ekman_surge_xmax
% Script automatically generated by fit_ekman_surge_xmax.m
% Inputs : 
% shelf_width    = width (km)
% phi            = track angle (deg)
% foreward_speed = foreward speed (km/h)
% phi_spiral     = spiral flow (deg)

% R2    = 0.68737
% RMSE  = 24.3483
% MEAN  = -29.2935
% RANGE = -136.2412 - 48.3948

beta( 1 )= -6.7600e+01 ;
beta( 2 )= 5.8525e-03 ;
beta( 3 )= 6.8883e-01 ;
beta( 4 )= 1.1977e+00 ;

v=beta(1) + beta(2)*shelf_width .* phi + beta(3)*foreward_speed + beta(4)*phi_spiral;
